@@ -8,5 +8,5 @@ test_that("delete_vertices works", {
   g2 <- delete_vertices(g, "A")
   g3 <- delete_vertices(g, match("A", V(g)$name))
   
-  expect_that(graph.isomorphic(g2, g3), is_true())
+  expect_true(graph.isomorphic(g2, g3))
 })
